@@ -1,7 +1,6 @@
 from abc import ABC, abstractmethod
 from urllib.parse import urlparse
 
-import cloudscraper
 import requests
 
 from pytaku.conf import config
@@ -14,11 +13,11 @@ from .exceptions import (
 
 
 def create_session():
-    return cloudscraper.create_scraper(
-        {
-            "mobile": False,
-        }
-    )
+    session = requests.Session()
+    session.headers[
+        "User-Agent"
+    ] = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/94.0.4606.71 Safari/537.36"
+    return session
 
 
 class Site(ABC):
